pub struct RuleOverrideMatcher { /* private fields */ }Expand description
Matcher for per-directory overrides.
Overrides are applied from shallowest to deepest directory so child directories can refine parent behavior.
Implementations
Sourceimpl RuleOverrideMatcher
impl RuleOverrideMatcher
Sourcepub fn compile(
specs: &[DirectoryRuleOverride],
) -> Result<Self, OverrideCompileError>
pub fn compile( specs: &[DirectoryRuleOverride], ) -> Result<Self, OverrideCompileError>
Compile raw directory overrides into a matcher.
Sourcepub fn resolve(&self, path: &str, rule_id: &str) -> ResolvedRuleOverride
pub fn resolve(&self, path: &str, rule_id: &str) -> ResolvedRuleOverride
Resolve the effective override for a specific path and rule id.