parse_suppression

Function parse_suppression 

pub fn parse_suppression(line: &str) -> Option<Suppression>
Parse a line for suppression directives.

Returns None if no directive is found, or Some(Suppression) if a valid directive is present.

This function should be called on the raw line BEFORE preprocessing (so that comment content is visible).