parse_suppression_in_comments

Function parse_suppression_in_comments 

pub fn parse_suppression_in_comments(
    line: &str,
    masked_comments: &str,
) -> Option<Suppression>
Parse a line for suppression directives, but only if the directive occurs inside a masked comment span.

masked_comments should be the output of the comments-only preprocessor for the same line and language. The directive is accepted only if the directive prefix is fully masked (spaces) in masked_comments.