pub enum Language {
Show 21 variants
Rust,
Python,
JavaScript,
TypeScript,
Go,
Ruby,
C,
Cpp,
CSharp,
Java,
Kotlin,
Shell,
Swift,
Scala,
Sql,
Xml,
Php,
Yaml,
Toml,
Json,
Unknown,
}Expand description
Supported programming languages for preprocessing.
Each language has specific comment and string syntax that the preprocessor uses to correctly mask comments and strings.
Variants
Rust
Python
JavaScript
TypeScript
Go
Ruby
C
Cpp
CSharp
Java
Kotlin
Shell
Swift
Scala
Sql
Xml
Php
Yaml
Toml
Json
Unknown
Implementations
Sourceimpl Language
impl Language
Sourcepub fn comment_syntax(self) -> CommentSyntax
pub fn comment_syntax(self) -> CommentSyntax
Returns the comment syntax for this language.
Sourcepub fn string_syntax(self) -> StringSyntax
pub fn string_syntax(self) -> StringSyntax
Returns the string syntax for this language.