pub struct PreprocessOptions {
pub mask_comments: bool,
pub mask_strings: bool,
}Expand description
Preprocessing options.
mask_* controls whether the corresponding token class is replaced with spaces.
Regardless of masking, the preprocessor may still track strings when masking comments, so that comment markers inside strings do not start a comment.
Fields
mask_comments: boolmask_strings: boolImplementations
Sourceimpl PreprocessOptions
impl PreprocessOptions
pub fn none() -> Self
pub fn comments_only() -> Self
pub fn strings_only() -> Self
pub fn comments_and_strings() -> Self